#include "AneuMeshLoader.h"
#include "Files_not_found.h"
#include <iostream>
#include <fstream>

void AneuMeshLoader::LoadMesh(const std::string& filename)
{
	std::ifstream fin(filename);
	if (!fin) {
		throw Files_not_found();
	}
	else std::cout << "Open file\t" << filename << "\tsuccessfully" << std::endl;

	int number_of_nodes, dimension, number_of_elem, nodes_in_elem, number_of_bound, nodes_in_bound;

	fin >> number_of_nodes >> dimension;
	nodes.reserve(number_of_nodes);
	for (int i = 1; i <= number_of_nodes; ++i) {
		Node p_node;
		p_node.node_id = i;
		fin >> get<0>(p_node.coors) >> get<1>(p_node.coors) >> get<2>(p_node.coors);
		p_node.vertex = false;
		nodes.push_back(std::move(p_node));
	}

	fin >> number_of_elem >> nodes_in_elem;
	finite_elems.reserve(number_of_elem);
	for (int i = 0; i < number_of_elem; ++i) {
		Finite_Element p_elem;
		p_elem.element_id = i + 1;
		fin >> p_elem.material_id;
		p_elem.node_id.reserve(nodes_in_elem);
		for (int j = 0; j < nodes_in_elem; ++j) {
			int node_id;
			fin >> node_id;
			p_elem.node_id.push_back(node_id);
		}
		finite_elems.push_back(std::move(p_elem));

	}

	fin >> number_of_bound >> nodes_in_bound;
	boundary.reserve(number_of_bound);
	for (int i = 0; i < number_of_bound; ++i) {
		Boundary_Finite_Element p_bound;
		p_bound.element_id = i + 1;
		fin >> p_bound.surface_id;
		p_bound.node_id.reserve(nodes_in_bound);
		for (int j = 0; j < nodes_in_bound; ++j) {
			int node_id;
			fin >> node_id;
			nodes[node_id - 1].vertex = true;
			p_bound.node_id.push_back(node_id);
		}
		boundary.push_back(std::move(p_bound));

	}
}

